<?php

namespace EasyContent\WordPress\Implementation\Entity;

use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Source\Api\Entity\ImportedArticle;
use EasyContent\WordPress\Source\Entity\CachedArticle;
use EasyContent\WordPress\Source\Entity\Miscellaneous;
use EasyContent\WordPress\Source\Entity\PluginStorage;

final class DefaultPluginStorage implements PluginStorage
{
    private $posts;

    public function __construct()
    {
        $this->posts = new DbPostStorage;
    }

    public function getMiscellaneous()
    {
        $misc = Plugin::getInstance()->getMisc();
        return Miscellaneous::load($misc->accountName, $misc->projectName, $misc->editUrlBase);
    }

    public function saveMiscellaneous(Miscellaneous $miscellaneous)
    {
        $misc = Plugin::getInstance()->getMisc();

        $misc->accountName = $miscellaneous->getAccountName();
        $misc->projectName = $miscellaneous->getProjectName();
        $misc->editUrlBase = $miscellaneous->getEditUrlBase();
    }

    public function saveKey($key)
    {
        $settings = Plugin::getInstance()->getSettings();
        $settings->publicKey = $key;
        $settings->isPluginConnected = true;
    }

    public function save(ImportedArticle $article)
    {
        global $wpdb;

        if ($article->getRelatedPost()) {
            $this->posts->save($article->getRelatedPost());
            $this->saveArticleToPostRelation($article->getId(), $article->getRelatedPost()->getId());
        } else {
            $tableName = "{$wpdb->prefix}easycontent_article_post";
            $query = "DELETE FROM `{$tableName}` WHERE `article_id` = %d;";
            $wpdb->query($wpdb->prepare($query, $article->getId()));
        }

        if ($article->getCached()) {
            $this->saveArticleCache($article->getCached());
        } else {
            $tableName = "{$wpdb->prefix}easycontent_article";
            $query = "DELETE FROM `{$tableName}` WHERE `id` = %d;";
            $wpdb->query($wpdb->prepare($query, $article->getId()));
        }
    }

    /**
     * @param int $articleId
     * @param int $postId
     * @return void
     */
    private function saveArticleToPostRelation($articleId, $postId)
    {
        global $wpdb;
        $tableName = "{$wpdb->prefix}easycontent_article_post";
        $query = "SELECT `id` FROM `{$tableName}` WHERE `article_id` = %d AND `post_id` = %d LIMIT 1;";
        $query = $wpdb->prepare($query, $articleId, $postId);
        $id = $wpdb->get_var($query);

        if ($id !== null) {
            $wpdb->update($tableName, ['sync_time' => time()], ['id' => $id], ['%d'], ['%d']);
            return;
        }

        $wpdb->insert(
            $tableName,
            [
                'article_id' => $articleId,
                'post_id' => $postId,
                'sync_time' => time(),
            ],
            ['%d', '%d', '%d']
        );
    }

    private function saveArticleCache(CachedArticle $cachedArticle)
    {
        global $wpdb;
        $tableName = "{$wpdb->prefix}easycontent_article";
        $query = "SELECT `id` FROM `{$tableName}` WHERE `id` = %d LIMIT 1;";
        $query = $wpdb->prepare($query, $cachedArticle->getId());
        $id = $wpdb->get_var($query);

        if ($id !== null) {
            $wpdb->update(
                $tableName,
                [
                    'current_workflow_stage_id' => $cachedArticle->getCurrentWorkflowStatusId(),
                    'topic_name'  => $cachedArticle->getTopicName(),
                    'title'       => $cachedArticle->getTitle(),
                    'updated'     => $cachedArticle->getUpdated(),
                ],
                ['id' => $cachedArticle->getId()],
                null,
                ['%d']
            );
            return;
        }

        $wpdb->insert(
            $tableName,
            [
                'id' => $cachedArticle->getId(),
                'current_workflow_stage_id' => $cachedArticle->getCurrentWorkflowStatusId(),
                'topic_name'  => $cachedArticle->getTopicName(),
                'title'       => $cachedArticle->getTitle(),
                'updated'     => time(),
            ],
            ['%d', '%d', '%s', '%s', '%d']
        );
    }
}
