<?php

namespace EasyContent\WordPress\Implementation\Entity\Misc;

use InvalidArgumentException;

final class RefererScheme
{
    const HTTP  = 'http';
    const HTTPS = 'https';

    private $value;

    /**
     * @param string $scheme
     */
    public function __construct($scheme)
    {
        if (!is_string($scheme)) {
            throw new InvalidArgumentException('Referer scheme must be string');
        }

        $normalized = mb_strtolower($scheme, 'UTF-8');

        if ($normalized !== self::HTTP && $normalized !== self::HTTPS) {
            $message = sprintf('Invalid scheme "%s". Only "%s" and "%s" allowed.', $scheme, self::HTTP, self::HTTPS);
            throw new InvalidArgumentException($message);
        }

        $this->value = $normalized;
    }

    /**
     * @return string
     */
    public function asString()
    {
        return $this->value;
    }

    public function __toString()
    {
        return $this->asString();
    }
}
