<?php

namespace EasyContent\WordPress;

use EasyContent\WordPress\Db\Models\Article;
use EasyContent\WordPress\Source\UseCase\PushPost\Command as PushPostCommand;
use EasyContent\WordPress\Source\UseCase\PushPost\Handler as PushPostHandler;
use EasyContent\WordPress\Source\UseCase\PullPost\Command as PullPostCommand;
use EasyContent\WordPress\Source\UseCase\PullPost\Handler as PullPostHandler;

class ListTableManager
{
    const COLUMN_SLUG = 'easycontent_status';


    public function __construct()
    {
        add_filter( 'manage_post_posts_columns', [$this, 'addCustomColumn'], 10000, 1 );
        add_filter( 'manage_page_posts_columns', [$this, 'addCustomColumn'], 10000, 1 );

        add_action( 'manage_post_posts_custom_column', [$this, 'renderColumnValue'], 10, 2 );
        add_action( 'manage_page_posts_custom_column', [$this, 'renderColumnValue'], 10, 2 );

        add_action( 'bulk_edit_custom_box', [$this, 'renderEditButtons'], 10, 2 );
        add_action( 'quick_edit_custom_box', [$this, 'renderEditButtons'], 10, 2 );

        add_action( 'init', [$this, 'handleBulkActions'] );
        add_action( 'admin_notices', [$this, 'renderNotices'] );
    }


    public function addCustomColumn($postsColumns)
    {
        $postsColumns[self::COLUMN_SLUG] = __( 'EasyContent Status', EASYCONTENT_TXTDOMAIN );

        return $postsColumns;
    }


    public function renderColumnValue($columnName, $postId)
    {
        if ( self::COLUMN_SLUG !== $columnName ) {
            return;
        }

        try {
            $article = Article::getByPostId( $postId );

            if ( ! $article ) {
                echo '&mdash;';
                return;
            }

            $workflowStage = $article->getCurrentWorkflowStage();

            if ( ! $workflowStage ) {
                echo '&mdash;';
                return;
            }

            // TODO: Move styles to another place
            $layout  = '<span class="" style="background-color: #%s; display: inline-block; width: 20px; height: 20px; border-radius: 50%%;"></span> ';
            $layout .= '<a target="_blank" href="%s">%s</a>';

            printf( $layout, $workflowStage->color, $article->getEditRemoteArticleUrl(), $workflowStage->name );
            return;
        } catch ( \Exception $e ) {  }

        echo '&mdash;';
    }


    public function renderEditButtons($columnName, $postType)
    {
        if ( $columnName !== self::COLUMN_SLUG ) {
            return;
        }

        if ( 'post' !== $postType && 'page' !== $postType ) {
            return;
        }

        echo (new View())->render( 'admin/bulk-actions' );
    }


    public function handleBulkActions()
    {
        if ( ! isset( $_GET['ec-action'] ) ) {
            return;
        }

        $action = sanitize_text_field( $_GET['ec-action'] );

        if ( 'pull' !== $action && 'push' !== $action ) {
            return;
        }

        $postIds = isset( $_GET['post'] )
            ? array_map( 'absint', (array)$_GET['post'] )
            : [];

        if ( ! $postIds ) {
            return;
        }

        $postsNumber = 0;
        $notices = [
            'success' => [],
            'error'   => [],
            'warning' => [],
            'info'    => []
        ];

        $container = Plugin::getInstance()->getContainer();

        /** @var PullPostHandler $pullPostHandler */
        $pullPostHandler = $container->get(PullPostHandler::class);
        /** @var PushPostHandler $pushPostHandler */
        $pushPostHandler = $container->get(PushPostHandler::class);

        foreach ( $postIds as $postId ) {
            try {
                if ('pull' === $action) {
                    $command = new PullPostCommand($postId);
                    $pullPostHandler->handle($command);
                } else {
                    $command = new PushPostCommand($postId);
                    $pushPostHandler->handle($command);
                }

                ++$postsNumber;
            } catch ( \Exception $e ) {
                $notices['error'][] = $e->getMessage();
            }
        }

        $notices['success'][] = 'pull' === $action
            ? _n(
                '%d article has been successfully pulled from EasyContent',
                '%d articles have been successfully pulled from EasyContent',
                $postsNumber,
                EASYCONTENT_TXTDOMAIN
            )
            : _n(
                '%d article has been successfully pushed to EasyContent',
                '%d articles have been successfully pushed to EasyContent',
                $postsNumber,
                EASYCONTENT_TXTDOMAIN
            );
    }


    public function renderNotices()
    {
        // TODO:
        $notices = [];

        foreach ( $notices as $noticeType => $rows ) {
            if ( $rows ) {
                ( new View() )->render( 'admin/notices/base', [
                    'type' => $noticeType,
                    'messages' => $rows
                ] );
            }
        }
    }



}
