<?php

namespace EasyContent\WordPress;

final class NoticesManager
{
    const TYPE_SUCCESS = 'success';
    const TYPE_ERROR   = 'error';
    const TYPE_INFO    = 'info';
    const TYPE_WARNING = 'warning';

    private $notices = [
        self::TYPE_SUCCESS => [],
        self::TYPE_ERROR   => [],
        self::TYPE_INFO    => [],
        self::TYPE_WARNING => []
    ];

    private function noticeTypeExists($type)
    {
        return ! ( ! $type || ! is_string( $type ) || ! array_key_exists( $type, $this->notices ) );
    }

    public function addNotice($notice, $type = self::TYPE_SUCCESS)
    {
        if ( ! is_string( $notice ) ) {
            return;
        }

        if ( ! $this->noticeTypeExists( $type ) ) {
            return;
        }

        $this->notices[$type][] = $notice;
    }

    public function renderNotices()
    {
        $layout = '';

        foreach ( $this->notices as $type => $notices ) {
            if ( ! $this->notices[$type] ) {
                continue;
            }

            $strings = implode( '<br>', $this->notices[$type] );
            $class = esc_attr( "notice notice-{$type} is-dismissible" );

            $layout .= '<div class="' . $class . '"><p>' . $strings . '</p></div>';
        }

        echo $layout;
    }
}
