<?php

namespace EasyContent\WordPress;

use EasyContent\WordPress\ValueObjects\PostStatus;
use EasyContent\WordPress\ValueObjects\PostType;

final class PostExtraDto
{
    /** @var PostType $postType */
    private $postType;
    /** @var PostStatus $postStatus */
    private $postStatus;
    /** @var array|int[] $categories */
    private $categories = [];
    /** @var array|int[] $tags */
    private $tags = [];
    /** @var null|\DateTimeImmutable $date */
    private $date;

    public function __construct(array $parameters)
    {
        $pluginSettings = Plugin::getInstance()->getSettings();

        $this->postType   = new PostType($pluginSettings->postType);
        $this->postStatus = new PostStatus($pluginSettings->postStatus);

        if (!empty($parameters['type'])) {
            try {
                $this->postType = new PostType($parameters['type']);
            } catch (\Exception $e) { }
        }

        if (!empty($parameters['status'])) {
            try {
                $this->postStatus = new PostStatus($parameters['status']);
            } catch (\Exception $e) { }
        }

        if ($this->postType->equals(PostType::post())) {
            $this->categories = !empty($parameters['categories']) ? $parameters['categories'] : []; // TODO: Validate category ids
            $this->tags = !empty($parameters['tags']) ? $parameters['tags'] : []; // TODO: Validate tags too
        }

        $dateTime = !empty($parameters['date'])
            ? \DateTimeImmutable::createFromFormat('Y-m-d H:i', $parameters['date'])
            : false;

        $dateTime = false === $dateTime ? null : $dateTime;

        if (null !== $dateTime) {
            $now = new \DateTimeImmutable();
            $interval = $now->diff($dateTime);

            if (0 === $interval->invert) {
                $this->date = $dateTime;
                $this->postStatus = PostStatus::future();
            }
        }
    }

    /**
     * @return PostType
     */
    public function getPostType()
    {
        return $this->postType;
    }

    /**
     * @return PostStatus
     */
    public function getPostStatus()
    {
        return $this->postStatus;
    }

    /**
     * @return array|int[]
     */
    public function getCategories()
    {
        return $this->categories;
    }

    /**
     * @return array|int[]
     */
    public function getTags()
    {
        return $this->tags;
    }

    /**
     * @return \DateTimeImmutable|null
     */
    public function getDate()
    {
        return $this->date;
    }
}
