<?php

namespace EasyContent\WordPress\Source\Api\Entity;

final class Category extends Entity implements EntityInterface
{
    /** @var int $id */
    private $id;
    /** @var int $parentCategoryId */
    private $parentCategoryId;
    /** @var string $name */
    private $name;

    private function __construct() { }

    /**
     * @param array $data
     * @return self
     */
    public static function fromState(array $data)
    {
        return (new self)
            ->setId($data)
            ->setParentCategoryId($data)
            ->setName($data);
    }

    /**
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @param array $data
     * @return Category
     */
    private function setId(array $data)
    {
        $this->ensureArrayKeyExists('id', $data);
        $this->ensureInteger($data['id']);
        $this->id = $data['id'];
        return $this;
    }

    /**
     * @return int
     */
    public function getParentCategoryId()
    {
        return $this->parentCategoryId;
    }

    /**
     * @param array $data
     * @return Category
     */
    private function setParentCategoryId(array $data)
    {
        $key = 'parent_category_id';
        $this->ensureArrayKeyExists($key, $data);
        $this->ensureInteger($data[$key]);
        $this->parentCategoryId = $data[$key];
        return $this;
    }

    /**
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param array $data
     * @return Category
     */
    private function setName(array $data)
    {
        $this->ensureArrayKeyExists('name', $data);
        $this->ensureString($data['name']);
        $this->name = $data['name'];
        return $this;
    }

    /**
     * @param Category $item
     * @return bool
     */
    public function fullyEquals($item)
    {
        return $this->id === $item->id
            && $this->parentCategoryId === $item->parentCategoryId
            && $this->name === $item->name;
    }
}
