<?php

namespace EasyContent\WordPress\Source\UseCase\Connect;

use EasyContent\WordPress\Source\Api\Entity\Article;
use EasyContent\WordPress\Source\Entity\CachedArticle;
use EasyContent\WordPress\Source\Entity\CachedArticlesStorage;
use EasyContent\WordPress\Source\Entity\CategoriesStorage;
use EasyContent\WordPress\Source\Entity\EasyContentStorage;
use EasyContent\WordPress\Source\Entity\PluginStorage;
use EasyContent\WordPress\Source\Entity\WorkflowStatusStorage;
use EasyContent\WordPress\Source\Services\CacheUpdater;

final class Handler
{
    private $remoteRepository;
    private $pluginStorage;
    private $categories;
    private $articles;
    private $statuses;
    private $cacheUpdater;

    public function __construct(
        EasyContentStorage $remoteRepository,
        PluginStorage $pluginStorage,
        CategoriesStorage $categories,
        CachedArticlesStorage $articles,
        WorkflowStatusStorage $statuses
    ) {
        $this->remoteRepository = $remoteRepository;
        $this->pluginStorage = $pluginStorage;
        $this->categories = $categories;
        $this->articles = $articles;
        $this->statuses = $statuses;
        $this->cacheUpdater = new CacheUpdater;
    }

    // TODO: Make some plugin object the root of aggregation in future.
    // It should work like: $plugin->connect($key) or something like that.
    // ...or maybe not, need to think about it
    public function handle(Command $command)
    {
        $key = $command->getPublicApiKey();
        $response = $this->remoteRepository->fetchAll($key);

        // Save miscellaneous plugin data
        $miscellaneous = $this->pluginStorage->getMiscellaneous()
            ->setAccountName($response->getAccountName())
            ->setProjectName($response->getProjectName())
            ->setEditUrlBase($response->getEditUrlBase());

        $this->pluginStorage->saveMiscellaneous($miscellaneous);
        $this->pluginStorage->saveKey($key);

        // Update cache of all tables
        $this->cacheUpdater->updateCache($this->categories, $response->getCategories());
        $this->cacheUpdater->updateCache($this->articles, $this->convertArticles($response->getArticles()));
        $this->cacheUpdater->updateCache($this->statuses, $response->getStages());
    }

    /**
     * @param array|Article[] $articles
     * @return array|CachedArticle[]
     */
    private function convertArticles(array $articles)
    {
        return array_map(function(Article $article) { return CachedArticle::fromSimple($article); }, $articles);
    }
}
