<?php

namespace EasyContent\WordPress\Source\UseCase\PullPost;

use EasyContent\WordPress\Source\Entity\Article\ArticleId;
use EasyContent\WordPress\Source\Entity\CachedArticlesStorage;
use EasyContent\WordPress\Source\Entity\EasyContentArticlesStorage;
use EasyContent\WordPress\Source\Entity\PluginSettings;
use EasyContent\WordPress\Source\Entity\Post\PostStorage;
use EasyContent\WordPress\Source\Exception\RemoteArticleNotFoundException;

final class Handler
{
    private $posts;
    private $remoteArticles;
    private $cachedArticles;
    private $pluginSettings;

    public function __construct(
        PostStorage $posts,
        EasyContentArticlesStorage $remoteArticles,
        CachedArticlesStorage $cachedArticles,
        PluginSettings $pluginSettings
    ) {
        $this->posts = $posts;
        $this->remoteArticles = $remoteArticles;
        $this->cachedArticles = $cachedArticles;
        $this->pluginSettings = $pluginSettings;
    }

    public function handle(Command $command)
    {
        $post = $this->posts->getById($command->getPostId());

        if (!$post->getRelatedArticleId()) {
            throw new \DomainException('Post was not synchronized. Push first!');
        }

        try {
            $remoteArticle = $this->remoteArticles->getById(new ArticleId($post->getRelatedArticleId()));
            $post->update($remoteArticle, $this->pluginSettings);
            $this->posts->save($post);
            $remoteArticle->updateLocalCache();
            $this->cachedArticles->save($remoteArticle->getCached());
        } catch (RemoteArticleNotFoundException $e) {
            $post->detachArticle();
            $this->cachedArticles->removeByIds([$post->getRelatedArticleId()]);

            throw $e;
        }
    }
}
