<?php

namespace EasyContent\WordPress\Source\UseCase\PushPost;

use EasyContent\WordPress\Source\Api\Entity\ImportedArticle;
use EasyContent\WordPress\Source\Entity\CachedArticlesStorage;
use EasyContent\WordPress\Source\Entity\EasyContentArticlesStorage;
use EasyContent\WordPress\Source\Entity\PluginSettings;
use EasyContent\WordPress\Source\Entity\Post\PostStorage;
use EasyContent\WordPress\Source\Entity\WorkflowStatusStorage;
use EasyContent\WordPress\Source\Services\CategoriesMapper;

final class Handler
{
    private $posts;
    private $pluginSettings;
    private $statuses;
    private $remoteArticles;
    private $cachedArticles;

    public function __construct(
        PostStorage $posts,
        PluginSettings $pluginSettings,
        WorkflowStatusStorage $statuses,
        EasyContentArticlesStorage $remoteArticles,
        CachedArticlesStorage $cachedArticles
    ) {
        $this->posts = $posts;
        $this->pluginSettings = $pluginSettings;
        $this->statuses = $statuses;
        $this->remoteArticles = $remoteArticles;
        $this->cachedArticles = $cachedArticles;
    }

    public function handle(Command $command)
    {
        $post = $this->posts->getById($command->getPostId());
        $wasNotSynced = !$post->getRelatedArticleId();

        $categories = $wasNotSynced
            ? CategoriesMapper::ecFromWpCategoriesIds(
                $this->pluginSettings,
                $post->getCategoriesIds()
            )
            : [];

        $draft = $this->statuses->getDraft();
        $article = ImportedArticle::fromPost($post, $draft->getId(), $categories);

        if ($wasNotSynced) {
            $this->remoteArticles->add($article);
            $post->attachArticle($article);
            $article->updateLocalCache();
            $this->cachedArticles->save($article->getCached(), $post);
        } else {
            $this->remoteArticles->update($article);
        }
    }
}
