<?php

namespace EasyContent\WordPress\ValueObjects;

final class PostType
{
    const POST = 'post';
    const PAGE = 'page';

    private $type;

    public function __construct($type)
    {
        if (self::POST !== $type && self::PAGE !== $type) {
            throw new \Exception("{$type} is invalid post type");
        }

        $this->type = $type;
    }

    /**
     * @return string
     */
    public function asString()
    {
        return $this->type;
    }

    /**
     * @param PostType $type
     * @return bool
     */
    public function equals(PostType $type)
    {
        return $this->asString() === $type->asString();
    }

    /**
     * @return PostType
     */
    public static function post()
    {
        return new self(self::POST);
    }

    /**
     * @return PostType
     */
    public static function page()
    {
        return new self(self::PAGE);
    }
}
