<?php

namespace EasyContent\WordPress;

class View
{
    protected $viewsDir;


    public function __construct($viewsDir = null)
    {
        $this->viewsDir = $viewsDir ?: EASYCONTENT_DIR . DIRECTORY_SEPARATOR . 'views';
        $this->viewsDir = $this->normalizePath( $this->viewsDir );

        if ( ! is_dir( $this->viewsDir ) ) {
            $message = __( 'Invalid views directory: %s', EASYCONTENT_TXTDOMAIN );
            throw new \Exception( sprintf( $message, $this->viewsDir ) );
        }
    }


    public function render($path, $params = [])
    {
        $fullPath = $this->getFullViewPath( $path );

        ob_start();
        extract( $params );
        require( $fullPath );
        return ob_get_clean();
    }


    public function getFullViewPath($relatedPath)
    {
        $fullPath = $this->viewsDir . DIRECTORY_SEPARATOR . "{$relatedPath}.php";
        $fullPath = $this->normalizePath( $fullPath );

        if ( ! is_file( $fullPath ) ) {
            $message = __( 'Can not find view file by path: %s', EASYCONTENT_TXTDOMAIN );
            throw new \Exception( sprintf( $message, $fullPath ) );
        }

        return $fullPath;
    }


    protected function normalizePath($path)
    {
        $path = str_replace( ['\\', '//'], DIRECTORY_SEPARATOR, $path );
        return rtrim( $path, DIRECTORY_SEPARATOR );
    }


    protected function renderGlobalNotices()
    {
        Plugin::getInstance()->noticesManager->renderNotices();
    }
}
