<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Implementation\Form\ConnectionForm;
use EasyContent\WordPress\Implementation\Form\Defaults\ConnectionFormDefaults;
use EasyContent\WordPress\NoticesManager;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Source\UseCase\Connect\Handler;
use EasyContent\WordPress\View;

class Connection extends BaseAction
{
    public function run()
    {
        $plugin = Plugin::getInstance();

        $form = new ConnectionForm(new ConnectionFormDefaults);
        $form->loadFromPost();

        if ($form->wasLoaded()) { // TODO: Validation
            try {
                /** @var Handler $handler */
                $handler = $plugin->getContainer()->get(Handler::class);
                $handler->handle($form->getCommand());

                $successMessage = (new View)->render('admin/pages/connection/success-message', [
                    'userName' => 0 == wp_get_current_user()->ID ? '' : wp_get_current_user()->display_name,
                    'accountName' => $plugin->getMisc()->accountName,
                ]);

                $plugin->noticesManager->addNotice($successMessage);
            } catch (\Exception $e) {
                $plugin->noticesManager->addNotice($e->getMessage(), NoticesManager::TYPE_ERROR);
            }
        }

        return $this->render( 'admin/pages/connection', [
            'form'        => $form,
            'isConnected' => $plugin->getSettings()->isPluginConnected,
            'projectName' => $plugin->getMisc()->projectName,
            'accountName' => $plugin->getMisc()->accountName,
            'projectUrl'  => str_replace( '/edit/', '', $plugin->getMisc()->editUrlBase ),
        ] );
    }
}
