<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Helpers\PublishingOptionsPageHelper;
use EasyContent\WordPress\Implementation\Entity\DbCategoriesStorage;
use EasyContent\WordPress\Implementation\Form\Defaults\PublishingOptionsFormDefaults;
use EasyContent\WordPress\Implementation\Form\PublishingOptionsForm;
use EasyContent\WordPress\Implementation\Formatters\CategoriesListFormatter;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Source\UseCase\RefreshCachedData\Handler as RefreshDataHandler;

class PublishingOptions extends BaseAction
{
    public function run()
    {
        $plugin = Plugin::getInstance();

        $form = new PublishingOptionsForm(new PublishingOptionsFormDefaults);
        $form->loadFromPost();

        if ($form->wasLoaded()) { // TODO: Validate
            $settings = $plugin->getSettings();

            $settings->postAuthorId   = $form->getPostAuthorId();
            $settings->postType       = $form->getPostType();
            $settings->postStatus     = $form->getPostStatus();
            $settings->commentsStatus = $form->getCommentsStatus();

            if ($form->getPostType() === 'post') {
                $settings->mappings = $form->getCategoriesMappings();
                $settings->defaultCategoryId = $form->getDefaultCategoryId();
            }

            $successMessage = __('Publishing options were saved successfully', EASYCONTENT_TXTDOMAIN);
            $plugin->noticesManager->addNotice($successMessage);
        }
        // TODO: Add errors
//        elseif ( count( $form->getErrors( true ) ) > 0 ) {
//            foreach ( $form->getErrors( true ) as $error ) {
//                $plugin->noticesManager->addNotice( $error->getMessage(), NoticesManager::TYPE_ERROR );
//            }
//        }


        if (isset($_POST['action'])) {
            $action = sanitize_text_field($_POST['action']);

            if ('refresh-all' === $action) {
                /** @var RefreshDataHandler $refreshDataHandler */
                $refreshDataHandler = $plugin->getContainer()->get(RefreshDataHandler::class);
                $refreshDataHandler->handle();

                // TODO: Add success/fail messages
            }
        }


        $postCategories = get_categories( ['hide_empty' => false] );
        $categoriesList = PublishingOptionsPageHelper::createCategoriesDataStructure( $postCategories );
        /** @var DbCategoriesStorage $categoriesRepository */
        $categoriesRepository = $plugin->getContainer()->get(DbCategoriesStorage::class);
        $categories = (new CategoriesListFormatter($categoriesRepository->all()))->asArray();

        return $this->render( 'admin/pages/publishing-options', [
            'form' => $form,
            'accountName' => $plugin->getMisc()->accountName,
            'projectName' => $plugin->getMisc()->projectName,
            'users' => get_users(),
            'categoriesList' => $categoriesList,
            'easyContentCategoriesList' => PublishingOptionsPageHelper::createCategoriesDataStructure(
                $categories, null, 'id', 'parent_category_id'
            )
        ] );
    }
}
