<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Implementation\Form\Defaults\SeoPluginSelectionFormDefaults;
use EasyContent\WordPress\Implementation\Form\SeoPluginSelectionForm;
use EasyContent\WordPress\Plugin;

class Seo extends BaseAction
{
    public function run()
    {
        $plugin  = Plugin::getInstance();
        $plugins = [];

        if ( is_plugin_active( 'all-in-one-seo-pack/all_in_one_seo_pack.php' ) ) {
            $plugins['All in One SEO Pack'] = 'all-in-one-seo-pack';
        }

        if ( is_plugin_active( 'wordpress-seo/wp-seo.php' ) ) {
            $plugins['Yoast SEO'] = 'yoast-seo';
        }

        $form = null;

        if ($plugins) {
            $form = new SeoPluginSelectionForm(new SeoPluginSelectionFormDefaults);
            $form->loadFromPost();

            if ($form->wasLoaded()) { // TODO: Validate
                $plugin->getSettings()->seoPlugin = $form->getSlug();

                $pluginName = array_search($form->getSlug(), $plugins);
                $successMessageTemplate = $pluginName
                    ? __('Success! %s plugin will be used.', EASYCONTENT_TXTDOMAIN)
                    : __('Success! No SEO plugin will be used.', EASYCONTENT_TXTDOMAIN);
                $successMessage = sprintf($successMessageTemplate, $pluginName);

                $plugin->noticesManager->addNotice( $successMessage );
            }

            // TODO: Add errors
//            foreach ( $form->getErrors( true ) as $error ) {
//                $plugin->noticesManager->addNotice( $error->getMessage(), NoticesManager::TYPE_ERROR );
//            }
        }

        return $this->render( 'admin/pages/seo', [
            'url'     => home_url(),
            'plugins' => $plugins,
            'form'    => $form,
        ] );
    }
}
