<?php

use EasyContent\WordPress\Implementation\Entity\DbCachedArticlesStorage;
use EasyContent\WordPress\Implementation\Entity\DbCategoriesStorage;
use EasyContent\WordPress\Implementation\Entity\DbPostStorage;
use EasyContent\WordPress\Implementation\Entity\DbWorkflowStatusStorage;
use EasyContent\WordPress\Implementation\Entity\DefaultPluginStorage;
use EasyContent\WordPress\Implementation\Entity\RemoteArticlesStorage;
use EasyContent\WordPress\Implementation\Entity\RemoteEasyContentStorage;
use EasyContent\WordPress\Implementation\Http\Client;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Source\Services\FrontendDataProvider;
use EasyContent\WordPress\Source\UseCase\Connect\Handler as ConnectHandler;
use EasyContent\WordPress\Source\UseCase\Import\Handler as ImportHandler;
use EasyContent\WordPress\Source\UseCase\PublishArticle\Handler as PublishArticleHandler;
use EasyContent\WordPress\Source\UseCase\PullPost\Handler as PullPostHandler;
use EasyContent\WordPress\Source\UseCase\PushPost\Handler as PushPostHandler;
use EasyContent\WordPress\Source\UseCase\RefreshCachedData\Handler as RefreshCachedDataHandler;
use EasyContent\WordPress\Source\UseCase\SetNewStatus\Handler as SetNewStatusHandler;

$getPluginSettings = function() {
    return Plugin::getInstance()->getSettings()->getDto();
};

return [
    \EasyContent\WordPress\Metaboxes\PostSyncMetaBox::class => [
        DbWorkflowStatusStorage::class,
    ],

    \EasyContent\WordPress\Rest\Actions\GetCategories::class => [],
    \EasyContent\WordPress\Rest\Actions\GetTags::class => [],
    \EasyContent\WordPress\Rest\Actions\PublishArticle::class => [],
    \EasyContent\WordPress\Rest\Actions\GetWorkflowStages::class => [
        DbWorkflowStatusStorage::class,
    ],
    \EasyContent\WordPress\Rest\Actions\SetArticleWorkflowStage::class => [],
    \EasyContent\WordPress\Rest\Actions\PushPost::class => [],
    \EasyContent\WordPress\Rest\Actions\UnlinkPost::class => [],
    \EasyContent\WordPress\Rest\Actions\GetArticleDetails::class => [],
    \EasyContent\WordPress\Rest\Actions\PullArticle::class => [],

    DbCategoriesStorage::class => [],
    DbWorkflowStatusStorage::class => [],
    FrontendDataProvider::class => [
        DbPostStorage::class,
        DbCachedArticlesStorage::class,
        DbWorkflowStatusStorage::class,
    ],
    RemoteArticlesStorage::class => [
        [Client::class, 'fromPluginSettings'],
    ],
    ConnectHandler::class => [
        RemoteEasyContentStorage::class,
        DefaultPluginStorage::class,
        DbCategoriesStorage::class,
        DbCachedArticlesStorage::class,
        DbWorkflowStatusStorage::class,
    ],
    ImportHandler::class => [
        DbWorkflowStatusStorage::class,
        RemoteArticlesStorage::class,
        DbCachedArticlesStorage::class,
        $getPluginSettings,
        DefaultPluginStorage::class,
    ],
    PublishArticleHandler::class => [
        RemoteArticlesStorage::class,
        $getPluginSettings,
        DbCachedArticlesStorage::class,
        DefaultPluginStorage::class,
    ],
    PullPostHandler::class => [
        DbPostStorage::class,
        RemoteArticlesStorage::class,
        DbCachedArticlesStorage::class,
        $getPluginSettings,
    ],
    PushPostHandler::class => [
        DbPostStorage::class,
        $getPluginSettings,
        DbWorkflowStatusStorage::class,
        RemoteArticlesStorage::class,
        DbCachedArticlesStorage::class,
    ],
    RefreshCachedDataHandler::class => [
        RemoteEasyContentStorage::class,
        DbCategoriesStorage::class,
        DbCachedArticlesStorage::class,
        DbWorkflowStatusStorage::class,
    ],
    SetNewStatusHandler::class => [
        RemoteArticlesStorage::class,
        DbWorkflowStatusStorage::class,
        DbCachedArticlesStorage::class,
        DbPostStorage::class,
    ],
];
