<?php

namespace EasyContent\WordPress\Domain\Seo;

use EasyContent\WordPress\Infrastructure\SeoPackPostRepository as Repository;
use EasyContent\WordPress\Plugin;

abstract class SeoPlugin
{
    const ALL_IN_ONE_SEO = 'all-in-one-seo-pack';
    const YOAST_SEO = 'yoast-seo';

    private $postRepository;

    final private function __construct(SeoPackPostRepository $postRepository)
    {
        $this->postRepository = $postRepository;
    }

    /**
     * @return SeoPackPostRepository
     */
    final protected function getPostRepository()
    {
        return $this->postRepository;
    }

    /**
     * @param string $slug
     * @return null|static
     */
    final public static function create($slug)
    {
        if ($slug !== self::ALL_IN_ONE_SEO && $slug !== self::YOAST_SEO) {
            return null;
        }

        $repository = new Repository();

        return $slug === self::ALL_IN_ONE_SEO
            ? new SeoPack($repository)
            : new Yoast($repository);
    }

    final public static function fromPluginSettings()
    {
        $seoPluginSlug = Plugin::getInstance()->getSettings()->getSeoPlugin();
        return self::create($seoPluginSlug);
    }

    /**
     * @param int $postId
     * @param string $title
     * @return void
     */
    abstract public function saveMetaTitle($postId, $title);

    /**
     * @param int $postId
     * @param string $description
     * @return void
     */
    abstract public function saveMetaDescription($postId, $description);

    /**
     * @param int $postId
     * @return string
     */
    abstract public function getMetaTitle($postId);

    /**
     * @param int $postId
     * @return string
     */
    abstract public function getMetaDescription($postId);
}
