<?php

namespace EasyContent\WordPress\Helpers;

class ArrayHelper
{
    /**
     * @param array $data Array of arrays or array of objects. If array of objects given, it will be returned as array of arrays
     * @param string $pk Primary key name
     * @param bool $removePk
     *
     * @return array
     */
    public static function indexByPrimaryKey(array $data = [], $pk = 'id', $removePk = false)
    {
        $indexedRows = [];

        foreach ( $data as $row ) {
            $rowArray = [];

            if ( is_object( $row ) ) {
                $reflection = null;

                try {
                    $reflection = new \ReflectionClass( $row );
                } catch ( \Exception $e ) {
                    continue;
                }

                $props = $reflection->getProperties( \ReflectionProperty::IS_PUBLIC );

                foreach ( $props as $property ) {
                    // Reflection gets wrong set of properties and property_exists() function works wrong
                    // if class has declared properties but some of them were unset() in user's code. So
                    // we are using array_key_exists() function to detect if property is still there
                    if ( $property->isStatic() || ! array_key_exists( $property->getName(), (array)$row ) ) {
                        continue;
                    }

                    $rowArray[$property->getName()] = $property->getValue( $row );
                }
            } elseif ( is_array( $row ) ) {
                $rowArray = $row;
            } else {
                continue;
            }

            if ( ! $rowArray ) {
                continue;
            }


            $row = $rowArray;

            if ( ! isset( $row[$pk] ) ) {
                continue;
            }

            if ( ! is_scalar( $row[$pk] ) && ! is_null( $row[$pk] ) ) {
                continue;
            }

            if ( isset( $indexedRows[$row[$pk]] ) ) {
                continue;
            }

            $indexedRows[$row[$pk]] = $row;

            if ( $removePk ) {
                unset($indexedRows[$row[$pk]][$pk]);
            }
        }

        return $indexedRows;
    }

    /**
     * @param array $data
     * @param string $sortBy
     * @param string $sort
     * @return array
     */
    public static function uSort(array $data, $sortBy, $sort = 'ASC')
    {
        usort($data, function($a, $b) use ($sortBy, $sort) {
            if (is_object($a) || is_object($b)) {
                $a = $a->{$sortBy};
                $b = $b->{$sortBy};
            } else {
                $a = $a[$sortBy];
                $b = $b[$sortBy];
            }

            if ($a == $b) {
                return 0;
            }

            if ($sort === 'ASC') {
                return ($a < $b) ? -1 : 1;
            }

            return ($a > $b) ? -1 : 1;
        });

        return $data;
    }

}
