<?php

namespace EasyContent\WordPress\Helpers;

class TimeHelper
{
    public static function ago($datetime, $isTimestamp = false, $full = false)
    {
        $now = new \DateTime();
        $ago = new \DateTime();
        $ago = $isTimestamp ? $ago->setTimestamp( $datetime ) : new \DateTime( $datetime );
        $diff = $now->diff($ago);

        $diff->w = (int)floor( $diff->d / 7 );
        $diff->d -= $diff->w * 7;

        $strings = [
            'y' => _n_noop( '%s year', '%s years', EASYCONTENT_TXTDOMAIN ),
            'm' => _n_noop( '%s month', '%s months', EASYCONTENT_TXTDOMAIN ),
            'w' => _n_noop( '%s week', '%s weeks', EASYCONTENT_TXTDOMAIN ),
            'd' => _n_noop( '%s day', '%s days', EASYCONTENT_TXTDOMAIN ),
            'h' => _n_noop( '%s hour', '%s hours', EASYCONTENT_TXTDOMAIN ),
            'i' => _n_noop( '%s minute', '%s minutes', EASYCONTENT_TXTDOMAIN ),
            's' => _n_noop( '%s second', '%s seconds', EASYCONTENT_TXTDOMAIN ),
        ];

        $message = [];

        foreach ( $strings as $propertyName => $translation ) {
            if ( 0 === $diff->$propertyName ) {
                continue;
            }

            $message[] = sprintf(
                translate_nooped_plural(
                    $strings[$propertyName],
                    $diff->$propertyName,
                    EASYCONTENT_TXTDOMAIN
                ),
                $diff->$propertyName
            );
        }

        if ( ! $full ) {
            $message = array_slice( $message, 0, 1 );
        }

        return $message
            ? implode( ', ', $message )
            : sprintf( __( '%s second', EASYCONTENT_TXTDOMAIN ), 1 );
    }


    public static function timestampToDate($timestamp, $format = 'F j, Y')
    {
        $d = new \DateTime();
        $d->setTimestamp( $timestamp );

        return $d->format( $format );
    }


    public static function getArticleListTableDateString($timestamp)
    {
        $secondsInWeek = 60 * 60 * 24 * 7;
        $weekAgo = time() - $secondsInWeek;

        return $weekAgo > $timestamp
            ? self::timestampToDate( $timestamp )
            : sprintf( __( '%s ago', EASYCONTENT_TXTDOMAIN ), self::ago( $timestamp, true ) );
    }
}
