<?php

namespace EasyContent\WordPress\Infrastructure;

use EasyContent\WordPress\Domain\Seo\SeoPackPost;
use EasyContent\WordPress\Domain\Seo\SeoPackPostRepository as Repository;

final class SeoPackPostRepository implements Repository
{
    /** @var \wpdb $db */
    private $db;

    /** @var string $tableName */
    private $tableName;

    public function __construct()
    {
        global $wpdb;

        if (!$wpdb) {
            throw new \Exception('$wpdb missing');
        }

        $this->db = $wpdb;
        $this->tableName = "{$wpdb->prefix}aioseo_posts";
    }

    public function find($id)
    {
        if (!$this->ensureTableExists()) {
            return null;
        }

        $query = "SELECT * FROM `{$this->tableName}` WHERE `id` = %d LIMIT 1";
        $query = $this->db->prepare($query, $id);

        $result = $this->db->get_row($query, ARRAY_A);

        return $result ? SeoPackPost::fromState($result) : null;
    }

    public function findByPostId($postId)
    {
        if (!$this->ensureTableExists()) {
            return null;
        }

        $query = "SELECT * FROM `{$this->tableName}` WHERE `post_id` = %d LIMIT 1";
        $query = $this->db->prepare($query, $postId);

        $result = $this->db->get_row($query, ARRAY_A);

        return $result ? SeoPackPost::fromState($result) : null;
    }

    public function update(SeoPackPost $seoPackPost)
    {
        if (!$this->ensureTableExists()) {
            return;
        }

        $this->db->update(
            $this->tableName,
            [
                'title' => $seoPackPost->getTitle(),
                'description' => $seoPackPost->getDescription(),
            ],
            [
                'id' => $seoPackPost->getId(),
                'post_id' => $seoPackPost->getPostId(),
            ],
            ['%s', '%s'],
            ['%d', '%d']
        );
    }

    /**
     * @return bool
     */
    private function ensureTableExists()
    {
        $dbname = $this->db->dbname; // Retrieved with __get
        $dbh = $this->db->dbh;       // Retrieved with __get

        $this->db->select('information_schema', $dbh);

        $query = "SELECT * FROM `TABLES` WHERE `TABLE_SCHEMA` = %s AND `TABLE_NAME` = %s LIMIT 1";
        $query = $this->db->prepare($query, $dbname, $this->tableName);

        $result = $this->db->get_row($query);

        $this->db->select($dbname, $dbh);

        return $result !== null;
    }
}
