<?php

namespace EasyContent\WordPress\Pages;

use EasyContent\WordPress\Controllers\Main;
use EasyContent\WordPress\Plugin;

final class PagesManager
{
    /** @var Main $controller */
    private $controller;

    public function __construct()
    {
        $this->controller = new Main;
        add_action( 'admin_menu', [$this, 'addMenuPages'], 1000 );
    }

    public function addMenuPages()
    {
        $plugin = Plugin::getInstance();

        add_menu_page(
            __( 'EasyContent', EASYCONTENT_TXTDOMAIN ),
            __( 'EasyContent', EASYCONTENT_TXTDOMAIN ),
            'activate_plugins',
            'easycontent-index',
            function() { }, // This page will never be shown
            'dashicons-networking',
            77
        );

        add_submenu_page(
            'easycontent-index',
            __( 'EasyContent', EASYCONTENT_TXTDOMAIN ),
            __( 'EasyContent connection', EASYCONTENT_TXTDOMAIN ),
            'activate_plugins',
            'easycontent-connection',
            $this->createCallback('connection')
        );

        if ( $plugin->getSettings()->isPluginConnected ) {
            add_submenu_page(
                'easycontent-index',
                __( 'Publishing options', EASYCONTENT_TXTDOMAIN ),
                __( 'Publishing options', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-publishing-options',
                $this->createCallback('publishing-options')
            );

            add_submenu_page(
                'easycontent-index',
                __( 'SEO settings', EASYCONTENT_TXTDOMAIN ),
                __( 'SEO settings', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-seo',
                $this->createCallback('seo')
            );

            add_submenu_page(
                'easycontent-index',
                __( 'Image processing', EASYCONTENT_TXTDOMAIN ),
                __( 'Image processing', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-image-processing',
                $this->createCallback('image-processing')
            );

            add_submenu_page(
                'easycontent-index',
                __( 'Import from EasyContent', EASYCONTENT_TXTDOMAIN ),
                __( 'Import from EasyContent', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-import',
                $this->createCallback('import')
            );
        }

        // Must be always at the end of the method
        remove_submenu_page( 'easycontent-index', 'easycontent-index' );
    }

    /**
     * @param string $slug
     * @return callable
     */
    private function createCallback($slug)
    {
        return function() use ($slug) {
            echo $this->controller->renderAction($slug);
        };
    }
}
