<?php

namespace EasyContent\WordPress\Rest\Actions;

use EasyContent\WordPress\Implementation\Entity\DbPostTaxonomiesStorage;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Source\Entity\Article\ArticleId;
use EasyContent\WordPress\Source\Entity\Article\Extra;
use EasyContent\WordPress\Source\Entity\Post\PostStatus;
use EasyContent\WordPress\Source\Entity\Post\PostType;
use EasyContent\WordPress\Source\UseCase\PublishArticle\Handler;
use EasyContent\WordPress\Source\UseCase\PublishArticle\Command;

class PublishArticle extends BaseAction
{
    protected $methods = ['POST'];


    public function run(\WP_REST_Request $request)
    {
        // URL: POST http://easycontent.wp/wp-json/easycontent/v1/posts

        if ( $request->get_body() === '' ) {
            return new \WP_Error( 4, __( 'Empty request body is not allowed', EASYCONTENT_TXTDOMAIN ) );
        }

        $data = json_decode( $request->get_body(), true );

        if ( null === $data || ! isset( $data['article_id'] ) ) {
            return new \WP_Error( 5, __( 'Article ID is required', EASYCONTENT_TXTDOMAIN ) );
        }

        try {
            $plugin  = Plugin::getInstance();
            /** @var Handler $handler */
            $handler = $plugin->getContainer()->get(Handler::class);

            $extra = empty($data['dataArticle'])
                ? null
                : Extra::fromArray(
                    $data['dataArticle'],
                    new PostType($plugin->getSettings()->postType),
                    new PostStatus($plugin->getSettings()->postStatus),
                    new DbPostTaxonomiesStorage
                );

            $command = new Command(
                new ArticleId((int)$data['article_id']),
                $extra
            );

            $handler->handle($command);

            return new \WP_REST_Response(null, 201);
        } catch ( \Exception $e ) {
            return new \WP_Error( $e->getCode(), $e->getMessage() );
        }
    }
}
