<?php

namespace EasyContent\WordPress\Rest\Actions;

use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Source\Services\FrontendDataProvider;
use EasyContent\WordPress\Source\UseCase\PullPost\Command;
use EasyContent\WordPress\Source\UseCase\PullPost\Handler;

class PullArticle extends BaseAction
{
    protected $methods = ['POST'];


    public function getArgumentsConfig()
    {
        return [
            'article_id' => [
                'type'              => 'integer',
                'required'          => true,
                'sanitize_callback' => 'absint'
            ]
        ];
    }


    public function run(\WP_REST_Request $request)
    {
        try {
            // TODO: Remove this quickfix from here to Gutenberg ReactJS frontend
            global $wpdb;
            $articleId = (int)$request['article_id'];
            $tableName = "{$wpdb->prefix}easycontent_article_post";
            $query = "SELECT `post_id` FROM `{$tableName}` WHERE `article_id` = %d LIMIT 1;";
            $query = $wpdb->prepare($query, $articleId);
            $postId = $wpdb->get_var($query);

            if (null === $postId) {
                throw new \Exception('Not synced!');
            }
            // End of quickfix



            $postId = (int)$postId;
            $container = Plugin::getInstance()->getContainer();

            $command = new Command($postId);
            /** @var Handler $handler */
            $handler = $container->get(Handler::class);

            $handler->handle($command);

            /** @var FrontendDataProvider $dataProvider */
            $dataProvider = $container->get(FrontendDataProvider::class);

            return new \WP_REST_Response($dataProvider->getData($postId));
        } catch (\Exception $e) { // TODO
            return new \WP_Error( $e->getCode(), $e->getMessage() );
        }
    }
}
