<?php
/**
 * @var EasyContent\WordPress\View $this
 * @var bool $isConnected
 * @var EasyContent\WordPress\Implementation\Form\ConnectionForm $form
 * @var string $accountName
 * @var string $projectName
 * @var string $projectUrl
 */
?>
<div class="wrap">
    <h1><?= esc_html( get_admin_page_title() ) ?></h1>

    <?php if ( $isConnected ) : ?>
        <h2 class="ec-header ec-header_green">
            You have successfully connected to <a href="<?= esc_url( $projectUrl ) ?>" target="_blank">
            <?= esc_html( $projectName ) ?></a> project in your "<?= esc_html( $accountName ) ?>" account.
        </h2>
    <?php endif ?>

    <?php $this->renderGlobalNotices() ?>

    <?php if ( ! $isConnected ) : ?>
        <p>
            <?= esc_html__( 'Set up your connection with EasyContent. You can find the instructions', EASYCONTENT_TXTDOMAIN ) ?>
            <a href="https://easycontent.io/help-article/wordpress-integration">
                <?= esc_html__( 'here', EASYCONTENT_TXTDOMAIN ) ?>
            </a>.
        </p>
    <?php endif ?>

    <form method="POST" novalidate="novalidate">
        <table class="form-table">
            <tbody>
                <tr>
                    <th scope="row">
                        <label for="ec-form-connection_field-public-key">
                            <?= esc_html__( 'API Key', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                    </th>
                    <td>
                        <input
                            type="text"
                            class="regular-text"
                            name="<?= esc_attr(sprintf('%s[%s]', $form::NAME, $form::FIELD_PUBLIC_KEY)) ?>"
                            id="ec-form-connection_field-public-key"
                            value="<?= esc_attr($form->getPublicKey()) ?>">
                    </td>
                </tr>
                <tr>
                    <th scope="row" style="padding-top: 0; padding-bottom: 0;">&nbsp;</th>
                    <td style="padding-top: 0; padding-bottom: 0;">
                        <p class="description" id="tagline-ec-private-api-key">
                            <a href="https://easycontent.io/help-article/wordpress-integration" target="_blank">
                                <?= esc_html__( 'How to get your API key?', EASYCONTENT_TXTDOMAIN ) ?>
                            </a>
                        </p>
                    </td>
                </tr>
            </tbody>
        </table>

        <p class="submit">
            <input type="submit" name="" id="submit" class="button button-primary" value="<?= esc_attr__( 'Save Changes', EASYCONTENT_TXTDOMAIN ) ?>">
            <?php if ( $isConnected ) : ?>
                <a href="<?= admin_url( 'admin.php?page=easycontent-publishing-options' ) ?>" class="button">
                    <?= esc_html__( 'Proceed to publishing options', EASYCONTENT_TXTDOMAIN ) ?>
                </a>
            <?php endif ?>
        </p>
    </form>
</div>
