<?php
/**
 * @var EasyContent\WordPress\View $this
 * @var Symfony\Component\Form\FormView $formView
 * @var EasyContent\WordPress\Implementation\Form\ImageProcessingForm $form
 */
?>
<div class="wrap">
    <h1>EasyContent</h1>

    <?php $this->renderGlobalNotices() ?>

    <h2><?= esc_html( get_admin_page_title() ) ?></h2>

    <form method="post" novalidate="novalidate">
        <table class="form-table">
            <tbody>
                <tr>
                    <th scope="row">
                        <label for="ec-form-image-processing_field-enable-resizing">
                            <?= esc_html__( 'Enable resizing', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                    </th>
                    <td>
                        <input type="hidden" name="<?= esc_attr(sprintf('%s[%s]', $form::NAME, $form::FIELD_ENABLE_RESIZING)) ?>" value="">
                        <input
                            name="<?= esc_attr(sprintf('%s[%s]', $form::NAME, $form::FIELD_ENABLE_RESIZING)) ?>"
                            type="checkbox"
                            id="ec-form-image-processing_field-enable-resizing"
                            value="1"
                            <?php checked($form->enableResizing()) ?>>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <?= esc_html__( 'Max image dimensions', EASYCONTENT_TXTDOMAIN ) ?>
                    </th>
                    <td>
                        <label for="ec-form-image-processing_field-max-width">
                            <?= esc_html__( 'Max width', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                        <input
                            name="<?= esc_attr(sprintf('%s[%s]', $form::NAME, $form::FIELD_MAX_WIDTH)) ?>"
                            id="ec-form-image-processing_field-max-width"
                            type="number"
                            step="1"
                            min="0"
                            value="<?= esc_attr($form->getMaxWidth()) ?>"
                            class="small-text">

                        <label for="ec-form-image-processing_field-max-height">
                            <?= esc_html__( 'Max height', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                        <input
                            name="<?= esc_attr(sprintf('%s[%s]', $form::NAME, $form::FIELD_MAX_HEIGHT)) ?>"
                            id="ec-form-image-processing_field-max-height"
                            type="number"
                            step="1"
                            min="0"
                            value="<?= esc_attr($form->getMaxHeight()) ?>"
                            class="small-text">

                        <p class="description">
                            <?= esc_html__( 'Set to zero to prevent resizing in that dimension.', EASYCONTENT_TXTDOMAIN ) ?>
                        </p>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="ec-form-image-processing_field-jpeg-compression-level">
                            <?= esc_html__( 'JPEG compression level', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                    </th>
                    <td>
                        <input
                            name="<?= esc_attr(sprintf('%s[%s]', $form::NAME, $form::FIELD_JPG_COMPRESSION_LEVEL)) ?>"
                            id="ec-form-image-processing_field-jpeg-compression-level"
                            type="number"
                            step="1"
                            min="1"
                            max="100"
                            value="<?= esc_attr($form->getJpgCompressionLevel()) ?>"
                            class="regular-text">

                        <p class="description">
                            <strong>1</strong> = <?= esc_html__( 'low quality (smallest files)', EASYCONTENT_TXTDOMAIN ) ?>
                        </p>
                        <p class="description">
                            <strong>100</strong> = <?= esc_html__( 'best quality (largest files)', EASYCONTENT_TXTDOMAIN ) ?>
                        </p>
                        <p class="description">
                            <?= esc_html__( 'Recommended value', EASYCONTENT_TXTDOMAIN ) ?>: <strong>90</strong>
                        </p>
                    </td>
                </tr>
            </tbody>
        </table>

        <p class="submit">
            <button type="submit" name="action" value="save-changes" id="submit" class="button button-primary">
                <?= esc_html__( 'Save Changes', EASYCONTENT_TXTDOMAIN ) ?>
            </button>
        </p>
    </form>

    <i><?= esc_html__( 'Note that any changes you make will only affect new images uploaded to your site via EasyContent.', EASYCONTENT_TXTDOMAIN ) ?></i>
</div>
